@@ -32,6 +32,8 @@
 #  Vestibulum commodo. Ut rhoncus gravida arcu.
 import logging
 ch = logging.StreamHandler()
+formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+ch.setFormatter(formatter)
 ch.setLevel(logging.INFO)
 log = logging.getLogger()
 log.setLevel(logging.DEBUG)
